@@ -1,4 +1,4 @@
 Repaic<-function(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1){
  aic(Dose, xaxis,yaxis,Totalplot,SingleRdata,SingleTdata,SingleRdata1,SingleTdata1,
-              separateWindows=TRUE,Demo=FALSE, BANOVA=FALSE,replicated=TRUE)
+              separateWindows=TRUE,Demo=FALSE, BANOVA=FALSE,replicated=TRUE, parallel=FALSE)
 }
\ No newline at end of file
