@@ -4,17 +4,17 @@ description_plot<-function()
 par(mar=c(0, 0, 0, 0)) 
 plot(0, xlim=c(0, 210), ylim=c(0, 297), col="white")
 text(100, 260,
-"~~~  This report was generated using bear v2.4.1. ~~~",cex = .8)
-text(80,240,"It was generated on: ",cex = .8)
-text(126,240,Sys.time(),cex = .8)
+"~~~  This report was generated using bear v2.4.2. ~~~",cex = .8)
+text(76,240,"and it was created on (local time): ",cex = .8)
+text(136,240,Sys.time(),cex = .8)
 text(100, 220,
 "bear was developed by Hsin-ya Lee & Yung-jin Lee.",cex = .8)
 text(100, 210,
 "College of Pharmacy, Kaohsiung Medical University &",cex = .8)
 text(100, 200,
-"Chunghwa Pharmaceutical Research Foundation,",cex = .8)
+"PharmaTek Pharmaceutical Consulting Ltd.,",cex = .8)
 text(100, 190,
-"Kaohsiung & Taipei, Taiwan",cex = .8)
+"Kaohsiung City, Taiwan",cex = .8)
 text(100, 180,
 "contact: Yung-jin Lee <mobilePK@gmail.com>",cex = .8)
 text(100, 170,
