@@ -1,16 +1,16 @@
 description_version<-function(){
-cat("~~~  This report was generated using bear v2.4.1 ~~~\n\n")
+cat("~~~  This report was generated using bear v2.4.2 ~~~\n\n")
 reportdate<-as.POSIXct(Sys.time())
-cat("It was generated on:- "); show(reportdate); cat("\n")
+cat("and was created on (local time):- "); show(reportdate); cat("\n")
 cat("bear was developed by Hsin-ya Lee & Yung-jin Lee.\n")
 cat("Contact: Yung-jin Lee <mobilePK@gmail.com> \n")
 cat("College of Pharmacy, Kaohsiung Medical University &\n")
-cat("Chunghwa Pharmaceutical Research Foundation,\n")
-cat("Kaohsiung & Taipei, Taiwan\n")
+cat("PharmaTek Pharmaceutical Consulting Ltd.,\n")
+cat("Kaohsiung City, Taiwan\n")
 cat("Internet websites:\n")
 cat("bear's website: http://pkpd.kmu.edu.tw/bear\n")
 cat("R website: http://www.r-project.org\n")
-cat("Users are recommedned to browse Bebac Forum: R for BE/BA ->\n") 
-cat("http://forum.bebac.at/?category=19 for more details.\n")
+cat("Users are strongly recommedned to browse Bebac Forum: R for BE/BA ->\n") 
+cat("http://forum.bebac.at/?category=19 for more details of bear.\n")
 cat("---------------------------------------------------\n")
 }
\ No newline at end of file
